@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "citar-typst" "1.0.0"
+(define-package "citar-typst" "20260301.2247"
   "Typst support for citar."
   '((emacs "29.1")
     (citar "1.4"))
